pub enum FormFieldError {
NoActivePage,
DuplicateName(String),
}Expand description
Errors that can occur when adding form fields to a document.
Variants
NoActivePage
add_text_field was called without an active page.
DuplicateName(String)
A field with the given name already exists in this document.