pub enum PdfMergeError {
NotSupported,
ReadError(PdfReadError),
Io(String),
}Expand description
Errors that can occur during a PDF merge operation.
Variants
NotSupported
A feature is requested that is not yet implemented.
ReadError(PdfReadError)
An error occurred while reading one of the source PDFs.
Io(String)
An I/O error occurred while writing the output file.