WordBreak

Enum WordBreak 

pub enum WordBreak {
    BreakAll,
    Hyphenate,
    Normal,
}
Controls how words wider than the available box width are handled.

Variants



BreakAll

Break wide words at a character boundary. (Default)



Hyphenate

Break wide words at a character boundary and insert a hyphen.



Normal

Do not break words. Wide words overflow the box.